package com.ruoyi.system.controller;

import java.net.UnknownHostException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.ip.IpUtils;
import com.ruoyi.system.mapper.TpInfoMapper;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TpInfo;
import com.ruoyi.system.service.ITpInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 投票信息Controller
 * 
 * @author ruoyi
 * @date 2024-10-11
 */
@RestController
@RequestMapping("/system/tpInfo")
public class TpInfoController extends BaseController
{
    @Autowired
    private ITpInfoService tpInfoService;

    @Autowired
    private TpInfoMapper tpInfoMapper;
    /**
     * 查询投票信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:tpInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(TpInfo tpInfo)
    {
        startPage();
        List<TpInfo> list = tpInfoService.selectTpInfoList(tpInfo);
        return getDataTable(list);
    }

    /**
     * 查询投票信息列表
     */
//    @PreAuthorize("@ss.hasPermi('system:tpInfo:listjg')")
    @GetMapping("/listjg")
    public TableDataInfo listjg(TpInfo tpInfo)
    {
        startPage();
        List<TpInfo> list = tpInfoService.selectTpInfoListjg(tpInfo);
        return getDataTable(list);
    }
    /**
     * 导出投票信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:tpInfo:export')")
    @Log(title = "投票信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TpInfo tpInfo)
    {
        List<TpInfo> list = tpInfoService.selectTpInfoList(tpInfo);
        ExcelUtil<TpInfo> util = new ExcelUtil<TpInfo>(TpInfo.class);
        util.exportExcel(response, list, "投票信息数据");
    }

    /**
     * 获取投票信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:tpInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tpInfoService.selectTpInfoById(id));
    }

    /**
     * 新增投票信息
     */
//    @PreAuthorize("@ss.hasPermi('system:tpInfo:add')")
//    @Log(title = "投票信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    public AjaxResult add(@RequestBody TpInfo tpInfo) throws UnknownHostException
    {
        return tpInfoService.insertTpInfo(tpInfo);
    }

    /**
     * 修改投票信息
     */
    @PreAuthorize("@ss.hasPermi('system:tpInfo:edit')")
    @Log(title = "投票信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TpInfo tpInfo)
    {
        return toAjax(tpInfoService.updateTpInfo(tpInfo));
    }

    /**
     * 删除投票信息
     */
    @PreAuthorize("@ss.hasPermi('system:tpInfo:remove')")
    @Log(title = "投票信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tpInfoService.deleteTpInfoByIds(ids));
    }
}
