package com.ruoyi.system.service.impl;

import java.net.Inet4Address;
import java.net.UnknownHostException;
import java.util.*;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ip.IpUtils;
import com.ruoyi.system.domain.TpDept;
import com.ruoyi.system.mapper.TpDeptMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.ruoyi.system.domain.TpInfoCb;
import com.ruoyi.system.mapper.TpInfoMapper;
import com.ruoyi.system.domain.TpInfo;
import com.ruoyi.system.service.ITpInfoService;

/**
 * 投票信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-11
 */
@Service
public class TpInfoServiceImpl implements ITpInfoService 
{
    @Autowired
    private TpInfoMapper tpInfoMapper;

    @Autowired
    private TpDeptMapper tpDeptMapper;

    /**
     * 查询投票信息
     * 
     * @param id 投票信息主键
     * @return 投票信息
     */
    @Override
    public TpInfo selectTpInfoById(Long id)
    {
        return tpInfoMapper.selectTpInfoById(id);
    }

    /**
     * 查询投票信息列表
     * 
     * @param tpInfo 投票信息
     * @return 投票信息
     */
    @Override
    public List<TpInfo> selectTpInfoList(TpInfo tpInfo)
    {
        return tpInfoMapper.selectTpInfoList(tpInfo);
    }

    /**
     * 新增投票信息
     * 
     * @param tpInfo 投票信息
     * @return 结果
     */
    @Transactional
    @Override
    public AjaxResult insertTpInfo(TpInfo tpInfo) throws UnknownHostException {
        Date nowDate = DateUtils.getNowDate();
        Date date = DateUtils.dateTime("yyyy-MM-dd HH:mm:ss", "2024-10-22 23:59:59");

        if(nowDate.after(date)){
            return AjaxResult.error("已过投票日期，不允许投票！");
        }

        String ipdz = Inet4Address.getLocalHost().getHostAddress();
//        String ip = IpUtils.getIpAddr();

        String adzh = tpInfo.getIpdz();// ad
        String tyzh = tpInfo.getYl1(); // 统一
        if(null==tyzh||"".equals(tyzh)){
            return AjaxResult.error("请重新登录");
        }
        if(null==adzh||"".equals(adzh)){
           adzh = tyzh;
        }
        tpInfo.setIpdz(tyzh);  //后续都存id
        //根据ip查询
        Map map = new HashMap();
        map.put("adzh", adzh);
        map.put("tyzh", tyzh);
        TpInfo tpInfo1=tpInfoMapper.selectTpInfoByIp(map);
        if(tpInfo1!=null){
           return AjaxResult.error("已投票，请勿重复投票");
        }
        tpInfo.setCreateTime(DateUtils.getNowDate());

        List<TpInfoCb> tpInfoCbListA = tpInfo.getTpInfoCbListA();
        List<TpInfoCb> tpInfoCbListB= tpInfo.getTpInfoCbListB();
        List<TpInfoCb> tpInfoCbListC= tpInfo.getTpInfoCbListC();
        List<TpInfoCb> tpInfoCbListD= tpInfo.getTpInfoCbListD();
        if(tpInfoCbListA.size()<=0){
            return AjaxResult.error("各板块至少选1家!");
        }
        if(tpInfoCbListB.size()<=0){
            return AjaxResult.error("各板块至少选1家!");
        }
        if(tpInfoCbListC.size()<=0){
            return AjaxResult.error("各板块至少选1家!");
        }
        if(tpInfoCbListD.size()<=0){
            return AjaxResult.error("各板块至少选1家!");
        }
        int sum=tpInfoCbListA.size()+tpInfoCbListB.size()+tpInfoCbListC.size()+tpInfoCbListD.size();
        if(sum<10 || sum>12){
            return AjaxResult.error("投票数请在10-12个单位之间");
        }
        tpInfo.getTpInfoCbList().addAll(tpInfoCbListA);
        tpInfo.getTpInfoCbList().addAll(tpInfoCbListB);
        tpInfo.getTpInfoCbList().addAll(tpInfoCbListC);
        tpInfo.getTpInfoCbList().addAll(tpInfoCbListD);
        List<TpDept> tpDepts = tpDeptMapper.selectTpDeptList(new TpDept());
        List<TpInfoCb> tpInfoCbList = tpInfo.getTpInfoCbList();
        tpInfoCbList.forEach(item->{
            TpDept tpDept1 = tpDepts.stream().filter(tpDept -> tpDept.getId().toString().equals(item.getDwid())).findFirst().orElse(null);
            if(tpDept1!=null){
                item.setDwmc(tpDept1.getDwmc());
                item.setSsbk(tpDept1.getSsbk());
            }
        });

        int rows = tpInfoMapper.insertTpInfo(tpInfo);
        insertTpInfoCb(tpInfo);
        return AjaxResult.success("投票成功！");
    }

    /**
     * 修改投票信息
     * 
     * @param tpInfo 投票信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateTpInfo(TpInfo tpInfo)
    {
        tpInfo.setUpdateTime(DateUtils.getNowDate());
        tpInfoMapper.deleteTpInfoCbByZbid(tpInfo.getId());
        insertTpInfoCb(tpInfo);
        return tpInfoMapper.updateTpInfo(tpInfo);
    }

    /**
     * 批量删除投票信息
     * 
     * @param ids 需要删除的投票信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteTpInfoByIds(Long[] ids)
    {
        tpInfoMapper.deleteTpInfoCbByZbids(ids);
        return tpInfoMapper.deleteTpInfoByIds(ids);
    }

    /**
     * 删除投票信息信息
     * 
     * @param id 投票信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteTpInfoById(Long id)
    {
        tpInfoMapper.deleteTpInfoCbByZbid(id);
        return tpInfoMapper.deleteTpInfoById(id);
    }

    @Override
    public List<TpInfo> selectTpInfoListjg(TpInfo tpInfo) {
        return tpInfoMapper.selectTpInfoListjg(tpInfo);
    }

    /**
     * 新增投票信息从信息
     * 
     * @param tpInfo 投票信息对象
     */
    public void insertTpInfoCb(TpInfo tpInfo)
    {
        List<TpInfoCb> tpInfoCbList = tpInfo.getTpInfoCbList();
        Long id = tpInfo.getId();
        if (StringUtils.isNotNull(tpInfoCbList))
        {
            List<TpInfoCb> list = new ArrayList<TpInfoCb>();
            for (TpInfoCb tpInfoCb : tpInfoCbList)
            {
                tpInfoCb.setZbid(id);
                list.add(tpInfoCb);
            }
            if (list.size() > 0)
            {
                tpInfoMapper.batchTpInfoCb(list);
            }
        }
    }
}
